@@ -192,6 +192,14 @@ class Client:
             endpoint=f"/core-game/v1/matches/{match_id}/loadouts", endpoint_type="glz")
         return data
 
+    def coregame_disassociate_player(self, match_id) -> dict:
+        '''
+        CoreGame_DisassociatePlayer
+        Leave a match
+        '''
+        data = self.post(endpoint=f"/core-game/v1/players/{self.puuid}/disassociate/{match_id}", endpoint_type="glz")
+        return data
+
     # matches endpoints
     def fetch_match_details(self, match_id) -> dict:
         '''
